@@ -20,6 +20,8 @@
 #include <aws/ecs/model/KeyValuePair.h>
 #include <aws/ecs/model/Tag.h>
 #include <aws/ecs/model/ClusterSetting.h>
+#include <aws/ecs/model/CapacityProviderStrategyItem.h>
+#include <aws/ecs/model/Attachment.h>
 #include <utility>
 
 namespace Aws
@@ -639,6 +641,255 @@ namespace Model
      */
     inline Cluster& AddSettings(ClusterSetting&& value) { m_settingsHasBeenSet = true; m_settings.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetCapacityProviders() const{ return m_capacityProviders; }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline bool CapacityProvidersHasBeenSet() const { return m_capacityProvidersHasBeenSet; }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline void SetCapacityProviders(const Aws::Vector<Aws::String>& value) { m_capacityProvidersHasBeenSet = true; m_capacityProviders = value; }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline void SetCapacityProviders(Aws::Vector<Aws::String>&& value) { m_capacityProvidersHasBeenSet = true; m_capacityProviders = std::move(value); }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline Cluster& WithCapacityProviders(const Aws::Vector<Aws::String>& value) { SetCapacityProviders(value); return *this;}
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline Cluster& WithCapacityProviders(Aws::Vector<Aws::String>&& value) { SetCapacityProviders(std::move(value)); return *this;}
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline Cluster& AddCapacityProviders(const Aws::String& value) { m_capacityProvidersHasBeenSet = true; m_capacityProviders.push_back(value); return *this; }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline Cluster& AddCapacityProviders(Aws::String&& value) { m_capacityProvidersHasBeenSet = true; m_capacityProviders.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The capacity providers associated with the cluster.</p>
+     */
+    inline Cluster& AddCapacityProviders(const char* value) { m_capacityProvidersHasBeenSet = true; m_capacityProviders.push_back(value); return *this; }
+
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline const Aws::Vector<CapacityProviderStrategyItem>& GetDefaultCapacityProviderStrategy() const{ return m_defaultCapacityProviderStrategy; }
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline bool DefaultCapacityProviderStrategyHasBeenSet() const { return m_defaultCapacityProviderStrategyHasBeenSet; }
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline void SetDefaultCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { m_defaultCapacityProviderStrategyHasBeenSet = true; m_defaultCapacityProviderStrategy = value; }
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline void SetDefaultCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { m_defaultCapacityProviderStrategyHasBeenSet = true; m_defaultCapacityProviderStrategy = std::move(value); }
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline Cluster& WithDefaultCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { SetDefaultCapacityProviderStrategy(value); return *this;}
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline Cluster& WithDefaultCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { SetDefaultCapacityProviderStrategy(std::move(value)); return *this;}
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline Cluster& AddDefaultCapacityProviderStrategy(const CapacityProviderStrategyItem& value) { m_defaultCapacityProviderStrategyHasBeenSet = true; m_defaultCapacityProviderStrategy.push_back(value); return *this; }
+
+    /**
+     * <p>The default capacity provider strategy for the cluster. When services or
+     * tasks are run in the cluster with no launch type or capacity provider strategy
+     * specified, the default capacity provider strategy is used.</p>
+     */
+    inline Cluster& AddDefaultCapacityProviderStrategy(CapacityProviderStrategyItem&& value) { m_defaultCapacityProviderStrategyHasBeenSet = true; m_defaultCapacityProviderStrategy.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline const Aws::Vector<Attachment>& GetAttachments() const{ return m_attachments; }
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline bool AttachmentsHasBeenSet() const { return m_attachmentsHasBeenSet; }
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline void SetAttachments(const Aws::Vector<Attachment>& value) { m_attachmentsHasBeenSet = true; m_attachments = value; }
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline void SetAttachments(Aws::Vector<Attachment>&& value) { m_attachmentsHasBeenSet = true; m_attachments = std::move(value); }
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline Cluster& WithAttachments(const Aws::Vector<Attachment>& value) { SetAttachments(value); return *this;}
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline Cluster& WithAttachments(Aws::Vector<Attachment>&& value) { SetAttachments(std::move(value)); return *this;}
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline Cluster& AddAttachments(const Attachment& value) { m_attachmentsHasBeenSet = true; m_attachments.push_back(value); return *this; }
+
+    /**
+     * <p>The resources attached to a cluster. When using a capacity provider with a
+     * cluster, the Auto Scaling plan that is created will be returned as a cluster
+     * attachment.</p>
+     */
+    inline Cluster& AddAttachments(Attachment&& value) { m_attachmentsHasBeenSet = true; m_attachments.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline const Aws::String& GetAttachmentsStatus() const{ return m_attachmentsStatus; }
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline bool AttachmentsStatusHasBeenSet() const { return m_attachmentsStatusHasBeenSet; }
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline void SetAttachmentsStatus(const Aws::String& value) { m_attachmentsStatusHasBeenSet = true; m_attachmentsStatus = value; }
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline void SetAttachmentsStatus(Aws::String&& value) { m_attachmentsStatusHasBeenSet = true; m_attachmentsStatus = std::move(value); }
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline void SetAttachmentsStatus(const char* value) { m_attachmentsStatusHasBeenSet = true; m_attachmentsStatus.assign(value); }
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline Cluster& WithAttachmentsStatus(const Aws::String& value) { SetAttachmentsStatus(value); return *this;}
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline Cluster& WithAttachmentsStatus(Aws::String&& value) { SetAttachmentsStatus(std::move(value)); return *this;}
+
+    /**
+     * <p>The status of the capacity providers associated with the cluster. The
+     * following are the states that will be returned:</p> <dl>
+     * <dt>UPDATE_IN_PROGRESS</dt> <dd> <p>The available capacity providers for the
+     * cluster are updating. This occurs when the Auto Scaling plan is provisioning or
+     * deprovisioning.</p> </dd> <dt>UPDATE_COMPLETE</dt> <dd> <p>The capacity
+     * providers have successfully updated.</p> </dd> <dt>UPDATE_FAILED</dt> <dd>
+     * <p>The capacity provider updates failed.</p> </dd> </dl>
+     */
+    inline Cluster& WithAttachmentsStatus(const char* value) { SetAttachmentsStatus(value); return *this;}
+
   private:
 
     Aws::String m_clusterArn;
@@ -670,6 +921,18 @@ namespace Model
 
     Aws::Vector<ClusterSetting> m_settings;
     bool m_settingsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_capacityProviders;
+    bool m_capacityProvidersHasBeenSet;
+
+    Aws::Vector<CapacityProviderStrategyItem> m_defaultCapacityProviderStrategy;
+    bool m_defaultCapacityProviderStrategyHasBeenSet;
+
+    Aws::Vector<Attachment> m_attachments;
+    bool m_attachmentsHasBeenSet;
+
+    Aws::String m_attachmentsStatus;
+    bool m_attachmentsStatusHasBeenSet;
   };
 
 } // namespace Model
