@@ -245,6 +245,31 @@ namespace Model
     inline GetApplicationResult& WithHomePageUrl(const char* value) { SetHomePageUrl(value); return *this;}
 
 
+    /**
+     * <p>Whether the author of this application has been verified. This means means
+     * that AWS has made a good faith review, as a reasonable and prudent service
+     * provider, of the information provided by the requester and has confirmed that
+     * the requester's identity is as claimed.</p>
+     */
+    inline bool GetIsVerifiedAuthor() const{ return m_isVerifiedAuthor; }
+
+    /**
+     * <p>Whether the author of this application has been verified. This means means
+     * that AWS has made a good faith review, as a reasonable and prudent service
+     * provider, of the information provided by the requester and has confirmed that
+     * the requester's identity is as claimed.</p>
+     */
+    inline void SetIsVerifiedAuthor(bool value) { m_isVerifiedAuthor = value; }
+
+    /**
+     * <p>Whether the author of this application has been verified. This means means
+     * that AWS has made a good faith review, as a reasonable and prudent service
+     * provider, of the information provided by the requester and has confirmed that
+     * the requester's identity is as claimed.</p>
+     */
+    inline GetApplicationResult& WithIsVerifiedAuthor(bool value) { SetIsVerifiedAuthor(value); return *this;}
+
+
     /**
      * <p>Labels to improve discovery of apps in search results.</p><p>Minimum
      * length=1. Maximum length=127. Maximum number of labels: 10</p><p>Pattern:
@@ -467,6 +492,49 @@ namespace Model
     inline GetApplicationResult& WithSpdxLicenseId(const char* value) { SetSpdxLicenseId(value); return *this;}
 
 
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline const Aws::String& GetVerifiedAuthorUrl() const{ return m_verifiedAuthorUrl; }
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline void SetVerifiedAuthorUrl(const Aws::String& value) { m_verifiedAuthorUrl = value; }
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline void SetVerifiedAuthorUrl(Aws::String&& value) { m_verifiedAuthorUrl = std::move(value); }
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline void SetVerifiedAuthorUrl(const char* value) { m_verifiedAuthorUrl.assign(value); }
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline GetApplicationResult& WithVerifiedAuthorUrl(const Aws::String& value) { SetVerifiedAuthorUrl(value); return *this;}
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline GetApplicationResult& WithVerifiedAuthorUrl(Aws::String&& value) { SetVerifiedAuthorUrl(std::move(value)); return *this;}
+
+    /**
+     * <p>The URL to the public profile of a verified author. This URL is submitted by
+     * the author.</p>
+     */
+    inline GetApplicationResult& WithVerifiedAuthorUrl(const char* value) { SetVerifiedAuthorUrl(value); return *this;}
+
+
     /**
      * <p>Version information about the application.</p>
      */
@@ -504,6 +572,8 @@ namespace Model
 
     Aws::String m_homePageUrl;
 
+    bool m_isVerifiedAuthor;
+
     Aws::Vector<Aws::String> m_labels;
 
     Aws::String m_licenseUrl;
@@ -514,6 +584,8 @@ namespace Model
 
     Aws::String m_spdxLicenseId;
 
+    Aws::String m_verifiedAuthorUrl;
+
     Version m_version;
   };
 
